==> cscec5b-rmat-api-3.0.1-20221107.095112-73-sources.jar: com/ejianc/business/rmat/vo/ExitApplyDetailVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 退场申请单明细
 * 
 * @author generator
 * 
 */
public class ExitApplyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pId; // 退场申请单ID
    private Integer referType; // 参照类型(1在场周转材2材料库)
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private String spec; // 型号
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private String unitId; // 档案单位id
    private String unitName; // 档案单位
    private String realUnitId; // 实物单位id
    private String realUnitName; // 实物单位
    private BigDecimal num; // 档案数量
    private BigDecimal rentNum; // 计租数量/在租数量
    private BigDecimal realNum; // 实物数量
    private BigDecimal rentTransScale; // 计租转换系数
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal rentExitNum; // 申请退场数量(计租)
    private BigDecimal realExitNum; // 申请退场数量(实物)
    private Date offRentDate; // 止租日
    private String memo; // 备注
    private String confirmFlagName;
    private String state; // 状态
    private Integer signRowType; // 合同签订方式1-分类，2-材料
    private Integer isTrue;//是否能编辑  不等于空能编辑

    public Long getPId() {
        return pId;
    }

    public void setPId(Long pId) {
        this.pId = pId;
    }
    public Integer getReferType() {
        return referType;
    }

    public void setReferType(Integer referType) {
        this.referType = referType;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentExitNum() {
        return rentExitNum;
    }

    public void setRentExitNum(BigDecimal rentExitNum) {
        this.rentExitNum = rentExitNum;
    }
    public BigDecimal getRealExitNum() {
        return realExitNum;
    }

    public void setRealExitNum(BigDecimal realExitNum) {
        this.realExitNum = realExitNum;
    }
    public Date getOffRentDate() {
        return offRentDate;
    }

    public void setOffRentDate(Date offRentDate) {
        this.offRentDate = offRentDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getConfirmFlagName() {
        return confirmFlagName;
    }

    public void setConfirmFlagName(String confirmFlagName) {
        this.confirmFlagName = confirmFlagName;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public Integer getSignRowType() {
        return signRowType;
    }

    public void setSignRowType(Integer signRowType) {
        this.signRowType = signRowType;
    }

    public Integer getIsTrue() {
        return isTrue;
    }

    public void setIsTrue(Integer isTrue) {
        this.isTrue = isTrue;
    }
}

==> cscec5b-rmat-api-3.0.1-20230712.113245-230-sources.jar: com/ejianc/business/rmat/vo/ExitApplyDetailVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonFormat.Shape;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 退场申请单明细
 *
 * @author generator
 *
 */
public class ExitApplyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long pId; // 退场申请单ID
    private Integer referType; // 参照类型(1在场周转材2材料库)
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private String spec; // 型号
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private String unitId; // 档案单位id
    private String unitName; // 档案单位
    private String realUnitId; // 实物单位id
    private String realUnitName; // 实物单位
    private BigDecimal num; // 档案数量
    private BigDecimal rentNum; // 计租数量/在租数量
    private BigDecimal realNum; // 实物数量
    private BigDecimal rentTransScale; // 计租转换系数
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal rentExitNum; // 申请退场数量(计租)
    private BigDecimal realExitNum; // 申请退场数量(实物)
    @JsonFormat(
            shape = Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date offRentDate; // 止租日
    private String memo; // 备注
    private String confirmFlagName;
    private String state; // 状态
    private Integer signRowType; // 合同签订方式1-分类，2-材料
    private Integer isTrue;//是否能编辑  不等于空能编辑
    private String unionId; // 联合主键

    public Long getPId() {
        return pId;
    }

    public void setPId(Long pId) {
        this.pId = pId;
    }
    public Integer getReferType() {
        return referType;
    }

    public void setReferType(Integer referType) {
        this.referType = referType;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentExitNum() {
        return rentExitNum;
    }

    public void setRentExitNum(BigDecimal rentExitNum) {
        this.rentExitNum = rentExitNum;
    }
    public BigDecimal getRealExitNum() {
        return realExitNum;
    }

    public void setRealExitNum(BigDecimal realExitNum) {
        this.realExitNum = realExitNum;
    }
    public Date getOffRentDate() {
        return offRentDate;
    }

    public void setOffRentDate(Date offRentDate) {
        this.offRentDate = offRentDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getConfirmFlagName() {
        return confirmFlagName;
    }

    public void setConfirmFlagName(String confirmFlagName) {
        this.confirmFlagName = confirmFlagName;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public Integer getSignRowType() {
        return signRowType;
    }

    public void setSignRowType(Integer signRowType) {
        this.signRowType = signRowType;
    }

    public Integer getIsTrue() {
        return isTrue;
    }

    public void setIsTrue(Integer isTrue) {
        this.isTrue = isTrue;
    }

    public Long getpId() {
        return pId;
    }

    public void setpId(Long pId) {
        this.pId = pId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }
}
